repo
stringclasses
15 values
fix_commit
stringlengths
40
40
buggy_commit
stringlengths
40
40
message
stringlengths
3
64.3k
files
listlengths
1
300
timestamp
timestamp[s]date
2013-03-13 20:45:00
2026-04-11 07:48:46
huggingface/transformers
62ce6fcb60ccd4e11d095893623cceedba4c6fe2
257fe5eea8ef22d03c5c48c2a7c95c5bf1017d33
Fix argument name in benchmarking script (#41086) * Fix argument name in benchmarking script * Adjust vars
[ { "path": "benchmark_v2/run_benchmarks.py", "patch": "@@ -347,7 +347,7 @@ def main():\n )\n \n parser.add_argument(\n- \"--upload-to-hub\",\n+ \"--push-to-hub\",\n type=str,\n help=\"Upload results to HuggingFace Dataset (provide dataset name, e.g., 'username/benchmark-...
2025-09-23T11:05:27
ggml-org/llama.cpp
86076f92de1a547ef87c304facca3b4b9fae6c21
bcbddcd54f0d5c22eab180831fdea6484107112f
OpenCL: add fused group_norm/norm, mul, add (#15314) * add fused group_norm/norm, mul, add * fix spacing * revert rms_norm logic * fix trailing whitespace
[ { "path": "ggml/src/ggml-opencl/ggml-opencl.cpp", "patch": "@@ -420,9 +420,9 @@ struct ggml_backend_opencl_context {\n cl_kernel kernel_clamp;\n cl_kernel kernel_geglu, kernel_reglu, kernel_swiglu, kernel_swiglu_oai, kernel_geglu_erf, kernel_geglu_quick,\n kernel_geglu_f16, kernel_regl...
2025-08-27T06:36:05
vuejs/vue
c2e6bf863756828fd1437eca299bb1e6b8fb6d91
6541e68aaa9fefbad0d3d96c02b5097749dc89a4
Fix links to docs in Readme (#3858) * Fix links to docs in Readme Fix #3857 * Rename reactivity system link to docs in readme
[ { "path": "README.md", "patch": "@@ -58,8 +58,8 @@ Vue.js is an MIT-licensed open source project. Its ongoing development is made p\n \n Vue.js is a library for building interactive web interfaces. It provides data-reactive components with a simple and flexible API. Core features include:\n \n-- [Dead simpl...
2016-10-05T20:04:32
denoland/deno
ac62d1dca3541686e53f1c883775cdbea0e1f628
9a8cb79986a8fbc9fc016f9c5e81c1bb4de5da16
ci: add AI PR generation (#31214) Should also fix the issue triager workflow which was missing the GH token.
[ { "path": ".github/workflows/ai_pr_generation.yml", "patch": "@@ -0,0 +1,85 @@\n+name: AI PR Generation\n+\n+on:\n+ issues:\n+ types: [labeled]\n+\n+jobs:\n+ generate-pr:\n+ if: github.event.label.name == 'ai:generate-pr'\n+ runs-on: ubuntu-latest\n+ permissions:\n+ contents: write\n+ ...
2025-11-06T18:30:41
ggml-org/llama.cpp
bcbddcd54f0d5c22eab180831fdea6484107112f
8b696861364360770e9f61a3422d32941a477824
tests : fix test-opt with GGML_BACKEND_DL (#15599)
[ { "path": "tests/test-opt.cpp", "patch": "@@ -3,7 +3,6 @@\n #include \"ggml.h\"\n #include \"ggml-alloc.h\"\n #include \"ggml-backend.h\"\n-#include \"ggml-cpu.h\"\n #include \"ggml-opt.h\"\n \n #include <cmath>\n@@ -899,6 +898,7 @@ static std::pair<int, int> test_backend(\n \n int main(void) {\n ggml_l...
2025-08-26T20:14:38
huggingface/transformers
257fe5eea8ef22d03c5c48c2a7c95c5bf1017d33
0ec03257810cae0c3f03190c6c09a9273e92ae09
Switch to `python:3.10-slim` for CircleCI docker images (#41067) fix Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "docker/consistency.dockerfile", "patch": "@@ -1,4 +1,4 @@\n-FROM python:3.9-slim\n+FROM python:3.10-slim\n ENV PYTHONDONTWRITEBYTECODE=1\n USER root\n ARG REF=main", "additions": 1, "deletions": 1, "language": "Unknown" }, { "path": "docker/custom-tokenizers.dockerfile", "...
2025-09-23T10:48:48
vuejs/vue
c835ce57ff4e0ba3617a189bb2736599f1ffb471
e6d224c3c5ca3ff6a365326ba615d116764b68f2
Allow text nodes on static templates in components (#3826) Fix #3824
[ { "path": "src/core/instance/render.js", "patch": "@@ -117,8 +117,10 @@ export function renderMixin (Vue: Class<Component>) {\n tree = this._staticTrees[index] = this.$options.staticRenderFns[index].call(this._renderProxy)\n if (Array.isArray(tree)) {\n for (let i = 0; i < tree.length; i++) {\...
2016-10-05T19:13:14
huggingface/transformers
0ec03257810cae0c3f03190c6c09a9273e92ae09
577fa6f1672ec3e8e4e6f27f47301b285560eded
Minor addition, no split modules for VideoMAEE (#41051) * added no split modules * fixed typo --------- Co-authored-by: Raushan Turganbay <raushan@huggingface.co>
[ { "path": "src/transformers/models/videomae/modeling_videomae.py", "patch": "@@ -402,6 +402,7 @@ class VideoMAEPreTrainedModel(PreTrainedModel):\n base_model_prefix = \"videomae\"\n main_input_name = \"pixel_values\"\n supports_gradient_checkpointing = True\n+ _no_split_modules = [\"VideoMAEE...
2025-09-23T09:53:51
denoland/deno
515e261d81ebf3a18af5cfbc297ad55d3899a976
004b85703a57b30b13d41a6d1fc44531dae83ddd
chore: fix install python ci step (#31204)
[ { "path": ".github/workflows/ci.generate.ts", "patch": "@@ -299,9 +299,16 @@ function withCondition(\n step: Record<string, unknown>,\n condition: string,\n ): Record<string, unknown> {\n+ function maybeParens(condition: string) {\n+ if (condition.includes(\"&&\") || condition.includes(\"||\")) {\n+...
2025-11-06T09:27:36
ggml-org/llama.cpp
8b696861364360770e9f61a3422d32941a477824
8ce3ff1d91245e158d98d8062cd64b0dd98dcfe3
SYCL: fix rms_norm_mul_add for tensor dim not a multiple of sg_size (#15592) The original implementation unconditionally returned true for this operation, leading to a failure when the tensor's first dimension (ne[0]) was not a multiple of WARP_SIZE. This caused an GGML_ASSERT(ncols % WARP_SIZE == 0) failure in ggml-s...
[ { "path": "ggml/src/ggml-sycl/ggml-sycl.cpp", "patch": "@@ -4364,11 +4364,12 @@ static bool ggml_backend_sycl_device_supports_op(ggml_backend_dev_t dev, const g\n return (op->type == GGML_TYPE_F32 && op->src[0]->type == GGML_TYPE_F32) && (op->type == op->src[0]->type);\n #endif\n case GG...
2025-08-26T18:57:49
vuejs/vue
1c79c56a3edc832d3b9e0bb34d31dacd9ff3390e
156cfb9892d3359d548e27abf5d8b78b421a5a92
revert npm main field (fix SSR externalization)
[ { "path": "package.json", "patch": "@@ -2,7 +2,7 @@\n \"name\": \"vue\",\n \"version\": \"2.0.0\",\n \"description\": \"Reactive, component-oriented view layer for modern web interfaces.\",\n- \"main\": \"dist/vue.js\",\n+ \"main\": \"dist/vue.common.js\",\n \"typings\": \"types/index.d.ts\",\n ...
2016-09-30T21:03:26
ggml-org/llama.cpp
8ce3ff1d91245e158d98d8062cd64b0dd98dcfe3
44b1efa41acd4df3f56ee0e46f898135ecd1a054
mtmd : fix mtmd ios build (#15579)
[ { "path": "tools/mtmd/CMakeLists.txt", "patch": "@@ -55,6 +55,8 @@ add_executable(llama-qwen2vl-cli deprecation-warning.cpp)\n set(TARGET llama-mtmd-cli)\n add_executable (${TARGET} mtmd-cli.cpp)\n set_target_properties (${TARGET} PROPERTIES OUTPUT_NAME llama-mtmd-cli)\n-install (TA...
2025-08-26T18:05:50
huggingface/transformers
577fa6f1672ec3e8e4e6f27f47301b285560eded
03c92884b5e52c95ab70cf12681b3f90dc71732d
fix crash when using chat to send 2+ request to gptoss (#40536) Signed-off-by: Wang, Yi <yi.a.wang@intel.com>
[ { "path": "src/transformers/commands/serving.py", "patch": "@@ -1026,7 +1026,9 @@ def generate_chat_completion(self, req: dict) -> Generator[str, None, None]:\n \n last_kv_cache = None\n if self.is_continuation(req) and not must_discard_cache:\n- last_kv_cache = self.last_kv_cache...
2025-09-23T09:50:23
denoland/deno
982658e8ec0927ef95299725a8eb48d3885ab9f2
4d2b56911f94089bc112f87fd9be4b1b16eb0abc
fix(lsp): lint-ignore directives follow leading comments (#31200)
[ { "path": "cli/lsp/analysis.rs", "patch": "@@ -1100,51 +1100,59 @@ impl CodeActionCollection {\n .actions\n .push(CodeActionKind::DenoLint(ignore_error_action));\n \n- // Disable a lint error for the entire file.\n- let maybe_ignore_comment = module\n+ let parsed_source = module\n ...
2025-11-06T07:53:23
vuejs/vue
8ef603b7c3a11a823f148aa2d86a4d243c35927d
51aa3e594ac0e194b8a0daa3b91a685287b27b07
test <template> key warning, fix coverage
[ { "path": "test/unit/modules/compiler/parser.spec.js", "patch": "@@ -120,6 +120,11 @@ describe('parser', () => {\n expect('Cannot use v-for on stateful component root element').toHaveBeenWarned()\n })\n \n+ it('warn <template> key', () => {\n+ parse('<div><template v-for=\"i in 10\" :key=\"i\"></t...
2016-09-30T18:18:47
ggml-org/llama.cpp
0373486dbc0dccbdcb3b5fdd65759d88cec06196
62cef26ac5b6b7acb635d3dc963813b43952dc2b
graph : fix assert in memory-less build_attn (#15590) ggml-ci
[ { "path": "src/llama-graph.cpp", "patch": "@@ -1376,7 +1376,7 @@ ggml_tensor * llm_graph_context::build_attn(\n \n // [TAG_NO_CACHE_PAD]\n // TODO: if ubatch.equal_seqs() == true, we can split the three tensors below into ubatch.n_seqs_unq streams\n- assert(!ubatch.equal_seqs());\n+ assert(!ub...
2025-08-26T14:45:17
huggingface/transformers
cbb290ec23ccd9b5c1d1ff4d333477449891debb
8048c614bfc65209df4ec18a431cedd128ddf714
Improve documentation and errors in Mamba2-based models (#41063) * fix bug in Mamba2 docs * correct 'because on of' issue * link to other Mamba2 model types * github URL is not changed * update error message in generated files
[ { "path": "docs/source/en/model_doc/mamba2.md", "patch": "@@ -1,4 +1,4 @@\n-<!--Copyright 2024 The HuggingFace Team. All rights reserved.\n+<!--Copyright 2025 The HuggingFace Team. All rights reserved.\n \n Licensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in...
2025-09-22T17:36:20
denoland/deno
2eb03415269cdbb8f22551a4769b3cbd14d2dc53
42cca89b074c7f4f09dfd8d9d4c6dfb7a580f7e7
fix(lsp): set lockfile_skip_write unconditionally (#31191)
[ { "path": "cli/lsp/language_server.rs", "patch": "@@ -379,7 +379,6 @@ impl LanguageServer {\n specifiers: Vec<ModuleSpecifier>,\n referrer: ModuleSpecifier,\n force_global_cache: bool,\n- lockfile_skip_write: bool,\n ) -> LspResult<Option<Value>> {\n async fn create_graph_for_caching(\n...
2025-11-05T14:27:29
vuejs/vue
99ea0f8229f108baa54f8791758315e2eda4f779
b8369e802b120e450f56e4c5ff8e3435a9165c64
adjust named slot resolve check (fix #3819)
[ { "path": "flow/component.js", "patch": "@@ -52,7 +52,7 @@ declare interface Component {\n _isVue: true;\n _self: Component;\n _renderProxy: Component;\n- _renderParent: ?Component;\n+ _renderContext: ?Component;\n _watcher: Watcher;\n _watchers: Array<Watcher>;\n _data: Object;", "additio...
2016-09-30T18:15:10
ggml-org/llama.cpp
b3964c1e890ef8c947afb36a5124ce6fcb2136d4
79a546220c719e6a70627b243a478ab8d84dc9e1
metal : optimize FA vec for large sequences and BS <= 8 (#15566) * metal : optmize FA vec for large heads and sequences * metal : adjust small-batch mul mv kernels ggml-ci * batched-bench : fix total speed computation ggml-ci * cont : add comments ggml-ci
[ { "path": "ggml/src/ggml-metal/ggml-metal-impl.h", "patch": "@@ -249,6 +249,7 @@ typedef struct {\n uint64_t nb33;\n int32_t ne1;\n int32_t ne2;\n+ int32_t ne3;\n float scale;\n float max_bias;\n float m0;\n@@ -257,6 +258,11 @@ typedef struct {\n float logit_sof...
2025-08-26T11:22:14
huggingface/transformers
aa30e0642e2697a83e8457d62f8e228789af26d0
1bb69cce820ee62889593ebe95efce5e795f16f7
Update quantization CI (#41068) * fix * new everything * fix
[ { "path": "docker/transformers-quantization-latest-gpu/Dockerfile", "patch": "@@ -1,4 +1,4 @@\n-FROM nvidia/cuda:12.1.1-cudnn8-devel-ubuntu22.04\n+FROM nvidia/cuda:12.6.0-cudnn-devel-ubuntu22.04\n LABEL maintainer=\"Hugging Face\"\n \n ARG DEBIAN_FRONTEND=noninteractive\n@@ -9,9 +9,9 @@ SHELL [\"sh\", \"-lc...
2025-09-22T16:10:16
denoland/deno
88aa2461c1ba0261e2ae9075b2e9a4d2b0a9d121
71db104c1f7c855680ae130c1e55a0fcc5144efd
fix(ext/node): implement `process.setgid()` and `process.setuid()` (#31162) Closes #31145, #31146
[ { "path": "ext/node/lib.rs", "patch": "@@ -459,6 +459,8 @@ deno_core::extension!(deno_node,\n ops::process::op_node_process_kill,\n ops::process::op_node_process_setegid<P>,\n ops::process::op_node_process_seteuid<P>,\n+ ops::process::op_node_process_setgid<P>,\n+ ops::process::op_node_pro...
2025-11-05T08:15:28
ggml-org/llama.cpp
79a546220c719e6a70627b243a478ab8d84dc9e1
85cc1ae998e4898d9fa992cb9b8620338cee97bf
mtmd : support Kimi VL model (#15458) * convert : fix tensor naming conflict for llama 4 vision * convert ok * support kimi vision model * clean up * fix style * fix calc number of output tokens * refactor resize_position_embeddings * add test case * rename build fn * correct a small bug
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -6254,9 +6254,11 @@ def prepare_tensors(self):\n raise ValueError(f\"Unprocessed experts: {experts}\")\n \n \n-@ModelBase.register(\"DeepseekV2ForCausalLM\")\n-@ModelBase.register(\"DeepseekV3ForCausalLM\")\n-@ModelBase.register(\"KimiVLForCond...
2025-08-26T10:54:19
huggingface/transformers
1bb69cce820ee62889593ebe95efce5e795f16f7
f15258dec24385bd9982ed9721797a33195343df
Fix CI jobs being all red 🔴 (false positive) (#41059) fix Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": ".github/workflows/model_jobs.yml", "patch": "@@ -141,8 +141,8 @@ jobs:\n script -q -c \"PATCH_TESTING_METHODS_TO_COLLECT_OUTPUTS=yes _PATCHED_TESTING_METHODS_OUTPUT_DIR=/transformers/reports/${{ env.machine_type }}_${{ inputs.report_name_prefix }}_${{ env.matrix_folders }}_test_reports ...
2025-09-22T14:51:00
vuejs/vue
b8369e802b120e450f56e4c5ff8e3435a9165c64
ef6945932f1cfd5e44111a5f1d0530e37b7d2ec3
fix test template typo
[ { "path": "test/unit/features/component/component-slot.spec.js", "patch": "@@ -316,7 +316,7 @@ describe('Component slot', () => {\n // #3254\n it('should not keep slot name when passed further down', () => {\n const vm = new Vue({\n- template: '<test><span slot=\"foo\">foo<span></test>',\n+ ...
2016-09-30T17:37:53
ggml-org/llama.cpp
4c37636b3ea96f2574eeb7668b93fcc0e64b05dd
34bdbbd7c2b70b848718e95bc48010f6aecd2816
Add a warning for special devices (#15563) * Add warning * Print the devices names * Add newlines * Apply suggestions from code review Co-authored-by: Johannes Gäßler <johannesg@5d6.de> * Fix vector names --------- Co-authored-by: Johannes Gäßler <johannesg@5d6.de>
[ { "path": "ggml/src/ggml-cuda/ggml-cuda.cu", "patch": "@@ -204,6 +204,8 @@ static ggml_cuda_device_info ggml_cuda_init() {\n GGML_LOG_INFO(\"%s: GGML_CUDA_FORCE_CUBLAS: no\\n\", __func__);\n #endif // GGML_CUDA_FORCE_CUBLAS\n GGML_LOG_INFO(\"%s: found %d \" GGML_CUDA_NAME \" devices:\\n\", __func__,...
2025-08-26T06:15:33
vuejs/vue
ef6945932f1cfd5e44111a5f1d0530e37b7d2ec3
47ee6abfc6d3584a825a61deb16ad03feb6105ec
Fix $createElement and Vue.extend (#3818) * Fix $createElement and extend * Add AsyncComponent
[ { "path": "types/index.d.ts", "patch": "@@ -6,6 +6,8 @@ import * as VNode from \"./vnode\";\n // `Vue` in `export = Vue` must be a namespace\n // All available types are exported via this namespace\n declare namespace Vue {\n+ export type Component = Options.Component;\n+ export type AsyncComponent = Opti...
2016-09-30T17:57:38
ggml-org/llama.cpp
f7207b0415986dd7f48447149da7de3a82338276
4d917cd4f64cc37744e76d084659475819fb0728
opencl: fix support ops condition for `rms_norm` (#15560)
[ { "path": "ggml/src/ggml-opencl/ggml-opencl.cpp", "patch": "@@ -2647,8 +2647,9 @@ static bool ggml_opencl_supports_op(ggml_backend_dev_t dev, const struct ggml_te\n return op->src[0]->type == GGML_TYPE_F32;\n case GGML_OP_SOFT_MAX:\n case GGML_OP_NORM:\n- case GGML_OP_RMS_...
2025-08-25T21:18:09
vuejs/vue
47ee6abfc6d3584a825a61deb16ad03feb6105ec
6d4bdb5ff196c3c67786f78b8ed7a0abd56eb310
remove codegen v-for truthiness check (fix #3817)
[ { "path": "src/compiler/codegen/index.js", "patch": "@@ -89,7 +89,7 @@ function genFor (el: any): string {\n const iterator1 = el.iterator1 ? `,${el.iterator1}` : ''\n const iterator2 = el.iterator2 ? `,${el.iterator2}` : ''\n el.forProcessed = true // avoid recursion\n- return `(${exp})&&_l((${exp})...
2016-09-30T02:05:39
ggml-org/llama.cpp
4d917cd4f64cc37744e76d084659475819fb0728
886b97a5d693550c2da470c091d9d27bf38398f8
vulkan: fix min subgroup 16 condition for mmid subgroup optimization (#15565)
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -2183,7 +2183,7 @@ static void ggml_vk_load_shaders(vk_device& device) {\n const uint32_t mul_mat_subgroup_size_32 = std::max(mul_mat_subgroup_size, 32u);\n \n const bool subgroup_min_size_16 = (!device->subgroup_size_control && device->...
2025-08-25T15:56:59
vuejs/vue
6d4bdb5ff196c3c67786f78b8ed7a0abd56eb310
82983231084d8649efd0eef9d613aa3e36f912da
fix style binding for falsy numbers (fix #3816)
[ { "path": "src/platforms/web/runtime/modules/style.js", "patch": "@@ -57,7 +57,7 @@ function updateStyle (oldVnode: VNodeWithData, vnode: VNodeWithData) {\n cur = style[name]\n if (cur !== oldStyle[name]) {\n // ie9 setting to null has no effect, must use empty string\n- el.style[normaliz...
2016-09-29T21:51:00
huggingface/transformers
c9939b3ab6f8dda4dea8a29a479755659c36ac96
4f36011545807a9d03a81bfd8fc4f1014badc02d
Remove repeated import (#40937) * Remove repeated import Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix conflict Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> --------- Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "src/transformers/data/data_collator.py", "patch": "@@ -737,8 +737,6 @@ def get_generator(self, seed):\n \n return torch.Generator().manual_seed(seed)\n else:\n- import numpy as np\n-\n return np.random.default_rng(seed)\n \n def create_rng(self):", ...
2025-09-22T12:57:13
denoland/deno
cc5a13315ef4588b5c86c7c20a64763ca7b24bbc
5eccca8717986ea7643638b41d2a78a818078b61
feat(process): support integer signals in Deno.kill and child.kill (#31153) Solution for https://github.com/denoland/deno/issues/30910 now this is valid: ```js function isRunning(pid: number): boolean { try { Deno.kill(pid, 0) return true } catch (e) { if (e instanceof Deno.errors.NotFound) { ...
[ { "path": "cli/tsc/dts/lib.deno.ns.d.ts", "patch": "@@ -3796,13 +3796,13 @@ declare namespace Deno {\n /** Waits for the child to exit completely, returning all its output and\n * status. */\n output(): Promise<CommandOutput>;\n- /** Kills the process with given {@linkcode Deno.Signal}.\n+ ...
2025-11-04T15:24:22
ggml-org/llama.cpp
111f8d06f0b9169059779a35f655b343242ccbb6
5eff6ec9b1220b599a43b594b1110487ab6aca08
metal: fix regression when no metal devices are present (#15531)
[ { "path": "ggml/src/ggml-metal/ggml-metal.m", "patch": "@@ -93,35 +93,37 @@\n if (ctx->mtl_device == nil) {\n ctx->mtl_device = MTLCreateSystemDefaultDevice();\n \n- ctx->has_simdgroup_reduction = [ctx->mtl_device supportsFamily:MTLGPUFamilyApple7];\n- ctx->has_simdgroup_reduction...
2025-08-25T15:27:34
vuejs/vue
f1e37f6002712465e7d67a7e9f84b2c9900b896c
b5595476f12b778ee0989d008bc5cec62011cef8
do not add list key to text nodes (fix #3810)
[ { "path": "src/core/vdom/helpers.js", "patch": "@@ -35,7 +35,7 @@ export function normalizeChildren (\n applyNS(c, ns)\n }\n // default key for nested array children (likely generated by v-for)\n- if (c.key == null && nestedIndex != null) {\n+ if (c.tag && c...
2016-09-29T16:52:05
huggingface/transformers
4f36011545807a9d03a81bfd8fc4f1014badc02d
2b8a7e82b5d0bc21fb1ecafe4412ae2600728acf
[testing] Fix `seed_oss` (#41052) * fix * fix * fix * fix * fix * fix * Update tests/models/seed_oss/test_modeling_seed_oss.py Co-authored-by: Anton Vlasjuk <73884904+vasqu@users.noreply.github.com> * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> Co-authored-by: Anton Vlasjuk <7388...
[ { "path": "tests/models/seed_oss/test_modeling_seed_oss.py", "patch": "@@ -90,54 +90,27 @@ class SeedOssIntegrationTest(unittest.TestCase):\n input_text = [\"How to make pasta?\", \"Hi ByteDance-Seed\"]\n model_id = \"ByteDance-Seed/Seed-OSS-36B-Base\"\n \n- def tearDown(self):\n+ def setUp(se...
2025-09-22T12:54:30
ggml-org/llama.cpp
5a6bc6b1a6cb665a944426c2055794950e524bf5
6b64f74b55628e4193f4fb00313f07dbd8556528
model-conversion : add model card template for embeddings [no ci] (#15557) * model-conversion: add model card template for embeddings [no ci] This commit adds a separate model card template (model repository README.md template) for embedding models. The motivation for this is that there server command for the embedd...
[ { "path": "examples/model-conversion/Makefile", "patch": "@@ -144,6 +144,15 @@ perplexity-run:\n hf-create-model:\n \t@./scripts/utils/hf-create-model.py -m \"${MODEL_NAME}\" -ns \"${NAMESPACE}\" -b \"${ORIGINAL_BASE_MODEL}\"\n \n+hf-create-model-dry-run:\n+\t@./scripts/utils/hf-create-model.py -m \"${MODEL...
2025-08-25T12:25:25
denoland/deno
16f6e2c3e8178e8435f4a9a2fbbecda4da7bea59
08a0846b4b08598a3e91cf7050e4040917600e1e
feat: V8 14.2 (#31178) Also locks `temporal_capi` to version 0.1.0, instead of using 0.1.1 which causes wrong calendar to by used by default. Closes https://github.com/denoland/deno/issues/30782 Closes https://github.com/denoland/deno/issues/30992 Closes https://github.com/denoland/deno/issues/30776 Closes https://gi...
[ { "path": "Cargo.lock", "patch": "@@ -791,9 +791,9 @@ checksum = \"1bf2a5fb3207c12b5d208ebc145f967fea5cac41a021c37417ccc31ba40f39ee\"\n \n [[package]]\n name = \"calendrical_calculations\"\n-version = \"0.2.2\"\n+version = \"0.2.3\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-chec...
2025-11-04T14:25:15
vuejs/vue
e29b711cb522b614fea3992697114f1b9e5dc690
e468ba078ebeb1870e1a477b7d5be6473d2dfc9f
fix reference to backers.md (#3808)
[ { "path": "README.md", "patch": "@@ -12,7 +12,7 @@\n \n ## Supporting Vue.js\n \n-Vue.js is an MIT-licensed open source project. Its ongoing development is made possible thanks to the support by these awesome [backers](https://github.com/vuejs/vue/blob/dev/backers.md). If you'd like to join them, check out ...
2016-09-29T08:19:42
ggml-org/llama.cpp
6b64f74b55628e4193f4fb00313f07dbd8556528
0d5a470223fc90b6b6807921d68011ff06ae7f9e
batched-bench : fix unified KV cache handling + pp timing (#15562) * batched-bench : fix unified KV cache handling + pp timing * cont : run dummy token only with split KV cache
[ { "path": "tools/batched-bench/batched-bench.cpp", "patch": "@@ -124,7 +124,7 @@ int main(int argc, char ** argv) {\n const int tg = n_tg[i_tg];\n const int pl = n_pl[i_pl];\n \n- const int n_ctx_req = is_pp_shared ? pp + pl*tg : pl*(pp + tg);\n+ ...
2025-08-25T10:56:43
huggingface/transformers
6eff44bb8db3c90614b45cc960e70c21bd5246c8
9ff47a71e4f75810387aba361c6153cdf8e48c69
Fix outdated torch version check (#40925) Update torch minimum version check to 2.2 Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "src/transformers/utils/import_utils.py", "patch": "@@ -236,9 +236,9 @@ def _is_package_available(pkg_name: str, return_version: bool = False) -> Union[\n \n _torch_available, _torch_version = _is_package_available(\"torch\", return_version=True)\n if _torch_available:\n- _torch_available = ver...
2025-09-22T12:38:07
denoland/deno
08a0846b4b08598a3e91cf7050e4040917600e1e
b885041588f060f2dacf35dc6e184b530b36ca92
chore: fix promote_to_release workflow (#31186) Part of https://github.com/denoland/deno/issues/31169
[ { "path": ".github/workflows/promote_to_release.yml", "patch": "@@ -48,7 +48,7 @@ jobs:\n - name: Run patchver for Windows\n shell: pwsh\n run: |\n- deno install -A -n patchver https://deno.land/x/patchver@0.2.0/cli.ts\n+ deno install -g -A -n patchver https://deno.la...
2025-11-04T13:43:07
vuejs/vue
e468ba078ebeb1870e1a477b7d5be6473d2dfc9f
f7e878c808ae69ed3d9b84f72eb21d59a8baa1be
fix coverage
[ { "path": "src/core/util/env.js", "patch": "@@ -61,9 +61,13 @@ export const nextTick = (function () {\n // \"force\" the microtask queue to be flushed by adding an empty timer.\n if (isIOS) setTimeout(noop)\n }\n- } else if (typeof MutationObserver !== 'undefined' && isNative(MutationObserv...
2016-09-29T00:58:16
ggml-org/llama.cpp
7da9fed0d6f1750a8783436f6f313b87e76e6378
c247d06f38fc09059c9607a28aa44f5ff6be208d
convert : support interns1-mini (#15412) * support interns1-mini * fix comment * update
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -1216,6 +1216,55 @@ def _try_set_pooling_type(self) -> None:\n raise NotImplementedError(\"Only MEAN, CLS, and LAST pooling types supported\")\n self.gguf_writer.add_pooling_type(pooling_type)\n \n+ def _set_vocab_interns1(self):...
2025-08-25T06:32:16
huggingface/transformers
9ff47a71e4f75810387aba361c6153cdf8e48c69
ae9ef2e1510eff1e9a620cad9648d0cca5c547cb
Fix condition for emitting warning when generation exceeds max model length (#40775) correct warning when generation exceeds max model length Signed-off-by: Yannick Schnider <yannick.schnider1@ibm.com>
[ { "path": "src/transformers/generation/stopping_criteria.py", "patch": "@@ -76,9 +76,9 @@ def __init__(self, max_length: int, max_position_embeddings: Optional[int] = Non\n def __call__(self, input_ids: torch.LongTensor, scores: torch.FloatTensor, **kwargs) -> torch.BoolTensor:\n cur_len = input...
2025-09-22T12:21:38
denoland/deno
945aebfe1f36e24173cf49be31d397ab59e1fe3d
6188ecc08d682592b585ab06d2fe560985c60dd9
ci: move lsp-tracing feature check to 'build-libs' job (#31173) This stage was needlessly slowing down the debug Linux build.
[ { "path": ".github/workflows/ci.generate.ts", "patch": "@@ -702,13 +702,6 @@ const ci = {\n run:\n \"deno run --allow-read --allow-env --allow-sys ./tools/jsdoc_checker.js\",\n },\n- {\n- name: \"Check tracing build\",\n- if:\n- \"matrix.job ...
2025-11-03T15:53:37
vuejs/vue
790c99cdb488883142d86122e006154882d3a30a
aefb34812ecfc54d231ca32e8bfddbb7377535d3
fix IE/Edge select remembering selection (#3803) * fix IE/Edge select remembering selection * Use const over let
[ { "path": "src/platforms/web/runtime/directives/model.js", "patch": "@@ -35,9 +35,11 @@ export default {\n setSelected(el, binding, vnode.context)\n /* istanbul ignore if */\n if (isIE || isEdge) {\n- nextTick(() => {\n+ const cb = () => {\n setSelected(el, binding,...
2016-09-28T19:32:59
huggingface/transformers
37152f84464dea9086dd1d88cd58f63c2129ee69
8a52288dba56a5c36cb7e1cf28da43ceaccd5808
Fix typos in English/Chinese documentation (#41031) * Fix typos and formatting in English docs Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * Fix typos and formatting in Chinese docs Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> --------- Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "docs/source/en/run_scripts.md", "patch": "@@ -104,7 +104,7 @@ torchrun \\\n ...\n ```\n \n-PyTorch supports TPUs, hardware designed to accelerate performance, through the [PyTorch/XLA](https://github.com/pytorch/xla/blob/master/README.md) package. Launch the `xla_spawn.py` script and use `num...
2025-09-22T11:31:46
ggml-org/llama.cpp
043fb27d3808766d8ea8195bbd12359727264402
b730706a49e576fb882dc34d9966345778b3ab0b
vulkan: apply MUL_MAT_ID subgroup optimization to non-coopmat devices (#15524) * vulkan: use subgroup function for mul_mat_id shader even without coopmat * vulkan: fix compile warnings * vulkan: properly check for subgroup size control and require full subgroups for subgroup mul_mat_id * vulkan: disable subgroup mu...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -388,6 +388,7 @@ struct vk_device_struct {\n bool float_controls_rte_fp16;\n bool subgroup_add;\n bool subgroup_shuffle;\n+ bool subgroup_ballot;\n bool multi_add;\n \n bool add_rms_fusion;\n@@ -1044,7 +1045,7 @@ struct vk...
2025-08-24T17:36:36
denoland/deno
6188ecc08d682592b585ab06d2fe560985c60dd9
d21201e2a0c022db4d370c447ec44e224a8808ed
ci: remove wpt_epoch job (#31171) This workflow is not useful anymore. It crashes constantly and requires manual intervention with every change. Gonna switch to manual updates.
[ { "path": ".github/workflows/wpt_epoch.yml", "patch": "@@ -1,80 +0,0 @@\n-# This CI job runs every night and tests all versions of Deno (canary and latest\n-# stable) across all OSes we support against the `epochs/daily` branch of WPT.\n-\n-name: wpt_epoch\n-\n-on:\n- schedule:\n- # Every night at 0:30 ...
2025-11-03T15:40:19
vuejs/vue
467572830f2df938796fd94300c590765963c1cc
313ad8f87bda5d0d120547f86ceb4995272f988e
fix coverage
[ { "path": "src/core/util/env.js", "patch": "@@ -21,6 +21,7 @@ export const isIOS = UA && /iphone|ipad|ipod|ios/.test(UA)\n // detect devtools\n export const devtools = inBrowser && window.__VUE_DEVTOOLS_GLOBAL_HOOK__\n \n+/* istanbul ignore next */\n function isNative (Ctor: Function): boolean {\n return ...
2016-09-27T02:56:08
huggingface/transformers
5f891b36cd0f7dae1843aa4a5a7c36d3f69f2ec0
c05f9d2f0e406912396c4fa1eef7ac53ff033425
Fix typing of tuples (#41028) * Fix tuple typing Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * More fixes Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> * More fixes Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> --------- Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": "src/transformers/image_processing_utils_fast.py", "patch": "@@ -131,7 +131,7 @@ def max_across_indices(values: Iterable[Any]) -> list[Any]:\n return [max(values_i) for values_i in zip(*values)]\n \n \n-def get_max_height_width(images: list[\"torch.Tensor\"]) -> tuple[int]:\n+def get_max_heigh...
2025-09-22T11:29:07
ggml-org/llama.cpp
a9c6ffcbfacee092bfaaa400306fceda18199737
e78cf0d4b1bdbbc2479f11d58ce0c8f51f755875
vulkan: enable Conv2D for Apple after MoltenVK fixed the bug (#15526)
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -11853,14 +11853,13 @@ static bool ggml_backend_vk_device_supports_op(ggml_backend_dev_t dev, const ggm\n // Op is disabled for Apple because it segfaults at pipeline create time on MoltenVK\n ggml_backend_vk_devi...
2025-08-24T08:48:53
denoland/deno
d21201e2a0c022db4d370c447ec44e224a8808ed
361c83ea35b7f78b79b358e4458d8e0f68529f0d
fix(ext/node): implement `process:seteuid()` (#31160) Closes #31144
[ { "path": "ext/node/lib.rs", "patch": "@@ -458,6 +458,7 @@ deno_core::extension!(deno_node,\n ops::ipc::op_node_ipc_unref,\n ops::process::op_node_process_kill,\n ops::process::op_node_process_setegid<P>,\n+ ops::process::op_node_process_seteuid<P>,\n ops::process::op_process_abort,\n ...
2025-11-03T14:30:21
vuejs/vue
313ad8f87bda5d0d120547f86ceb4995272f988e
43b489b11f81956fc832ddee4121cfd59287cc39
fix flow lifecycle method name [Vue@2.x] (#3762) fix lifecycle method name `init` to `beforeCreate`
[ { "path": "flow/options.js", "patch": "@@ -34,7 +34,7 @@ declare type ComponentOptions = {\n render: () => VNode;\n staticRenderFns?: Array<() => VNode>;\n // lifecycle\n- init?: Function;\n+ beforeCreate?: Function;\n created?: Function;\n beforeMount?: Function;\n mounted?: Function;", "...
2016-09-27T02:54:57
huggingface/transformers
c05f9d2f0e406912396c4fa1eef7ac53ff033425
55a1eaf6f08c86110b73a7b91cba9792f8c76ef2
[testing] Fix `qwen2_audio` (#41018) * fix * fix * fix * fix * fix * fix * fix * fix * fix * fix * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/qwen2_audio/test_modeling_qwen2_audio.py", "patch": "@@ -198,6 +198,7 @@ def test_sdpa_can_dispatch_composite_models(self):\n @require_torch\n class Qwen2AudioForConditionalGenerationIntegrationTest(unittest.TestCase):\n def setUp(self):\n+ cleanup(torch_device, gc_collect...
2025-09-22T10:45:31
ggml-org/llama.cpp
710dfc465a68f7443b87d9f792cffba00ed739fe
611f419cff11e4952228162a1c44cb35dff2274a
CUDA: fix half2 -> half conversion for HIP (#15529)
[ { "path": "ggml/src/ggml-cuda/fattn-tile-f16.cu", "patch": "@@ -258,7 +258,7 @@ static __global__ void flash_attn_tile_ext_f16(\n const half val = hexp(sink - kqmax[j0/nwarps]);\n kqsum[j0/nwarps] = kqsum[j0/nwarps] * KQ_max_scale;\n if (threadIdx.x == 0) {\n- ...
2025-08-23T19:37:06
vuejs/vue
43b489b11f81956fc832ddee4121cfd59287cc39
08f2b97083d32b8c3fe035d770dddfc19de49a7e
revert nextTick to microtask semantics by using Promise.then (fix #3771)
[ { "path": "src/core/util/env.js", "patch": "@@ -1,4 +1,7 @@\n /* @flow */\n+/* globals MutationObserver */\n+\n+import { noop } from 'shared/util'\n \n // can we use __proto__?\n export const hasProto = '__proto__' in {}\n@@ -13,61 +16,84 @@ export const isIE = UA && /msie|trident/.test(UA)\n export const i...
2016-09-27T02:38:43
denoland/deno
361c83ea35b7f78b79b358e4458d8e0f68529f0d
b04d451d48198370ff8a5e95ca31f587a8bae935
fix(ext/node): implement `process.setegid()` (#31155) Closes #31116
[ { "path": "Cargo.lock", "patch": "@@ -2523,6 +2523,7 @@ dependencies = [\n \"libz-sys\",\n \"md-5\",\n \"md4\",\n+ \"nix 0.27.1\",\n \"node_resolver\",\n \"num-bigint\",\n \"num-bigint-dig\",", "additions": 1, "deletions": 0, "language": "Unknown" }, { "path": "ext/node/Cargo.toml"...
2025-11-03T13:27:53
huggingface/transformers
55a1eaf6f08c86110b73a7b91cba9792f8c76ef2
db802aafa447c056956fd7cd01a5bac6200b3acf
Fix Qwen video tests (#41049) fix test
[ { "path": "src/transformers/models/qwen2_5_omni/processing_qwen2_5_omni.py", "patch": "@@ -62,8 +62,10 @@ class Qwen2_5OmniProcessorKwargs(ProcessingKwargs, total=False):\n \"seconds_per_chunk\": 2.0,\n \"position_id_per_seconds\": 25,\n \"use_audio_in_video\": False,\n- ...
2025-09-22T10:28:11
vuejs/vue
c791fc782616138f026e296472b0def916f68587
403f3ccb4ce5ecf920fde6b23615e11b772214b2
fix unit tests in IE9
[ { "path": "test/unit/features/component/component-keep-alive.spec.js", "patch": "@@ -1,6 +1,6 @@\n import Vue from 'vue'\n import injectStyles from '../transition/inject-styles'\n-import { isIE9 } from 'web/util/index'\n+import { isIE9 } from 'core/util/env'\n import { nextFrame } from 'web/runtime/transiti...
2016-09-23T22:16:43
ggml-org/llama.cpp
611f419cff11e4952228162a1c44cb35dff2274a
b1afcab804e3281867a5471fbd701e32eb32e512
vulkan: optimize rms_norm, and allow the work to spread across multiple SMs (#15281) * vulkan: optimize rms_norm, and allow the work to spread across multiple SMs There are really two parts to this change: (1) Some optimizations similar to what we have in soft_max, to unroll with different numbers of iterations. (2) ...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -102,9 +102,9 @@ static bool is_pow2(uint32_t x) { return x > 1 && (x & (x-1)) == 0; }\n \n struct ggml_backend_vk_context;\n \n-#define MAX_PARAMETER_COUNT 8\n+#define MAX_PARAMETER_COUNT 12\n // Max number of adds that can be fused without exc...
2025-08-23T18:16:17
denoland/deno
b04d451d48198370ff8a5e95ca31f587a8bae935
d607e0b01c225fc7ae54e6fb18ce61dcbd70effd
fix(cli): make --eval-file flag work without equals sign (#31151)
[ { "path": "cli/args/flags.rs", "patch": "@@ -3434,7 +3434,7 @@ TypeScript is supported, however it is not type-checked, only transpiled.\"\n .long(\"eval-file\")\n .num_args(1..)\n .action(ArgAction::Append)\n- .require_equals(true)\n+ .use_value_delimiter(tru...
2025-11-03T10:45:37
huggingface/transformers
8a2f24a321912efe9821991393cb28dcf88d0283
ebbcf00ad1b06fa87effe179d128e73390255844
Making compute_loss_func always take priority in Trainer (#40632) * logger warn, if-else logic improved * redundant if condition fix
[ { "path": "src/transformers/trainer.py", "patch": "@@ -4115,16 +4115,27 @@ def compute_loss(\n if self.args.past_index >= 0:\n self._past = outputs[self.args.past_index]\n \n- if labels is not None:\n+ # User-defined compute_loss function\n+ if self.compute_loss_func...
2025-09-22T09:47:34
vuejs/vue
403f3ccb4ce5ecf920fde6b23615e11b772214b2
c47e128eb65648a5e67db49d99bb7436e0df59fe
set selected value on nextTick in IE/Edge (fix #3689 by @fergaldoyle)
[ { "path": "src/platforms/web/runtime/directives/model.js", "patch": "@@ -4,7 +4,7 @@\n */\n \n import { looseEqual, looseIndexOf } from 'shared/util'\n-import { warn, isAndroid, isIE9 } from 'core/util/index'\n+import { warn, nextTick, isAndroid, isIE9, isIE, isEdge } from 'core/util/index'\n \n const mode...
2016-09-23T21:54:27
ggml-org/llama.cpp
b1afcab804e3281867a5471fbd701e32eb32e512
9ef536907de1b50c30e0369284898d30472a755a
model : add support for Seed-OSS (#15490) * First draft * Fix linter errors * Added missing sinks nullptr * Don't forget the llama-arch! * We're through to the generation stage. * Fix post-attention norm * Apply suggestions from code review Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com> * Fix R...
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -5854,6 +5854,11 @@ def modify_tensors(self, data_torch: Tensor, name: str, bid: int | None) -> Iter\n return [(self.map_tensor_name(name), data_torch)]\n \n \n+@ModelBase.register(\"SeedOssForCausalLM\")\n+class SeedOssModel(TextModel):\n+ model_ar...
2025-08-23T13:21:52
denoland/deno
d607e0b01c225fc7ae54e6fb18ce61dcbd70effd
be1ede505bf138b65d45ecbaa1b46bbce1812af1
fix(compile): support --preload flag in deno compile (#31152)
[ { "path": "cli/lib/standalone/binary.rs", "patch": "@@ -86,6 +86,7 @@ pub struct Metadata {\n pub env_vars_from_env_file: IndexMap<String, String>,\n pub workspace_resolver: SerializedWorkspaceResolver,\n pub entrypoint_key: String,\n+ pub preload_modules: Vec<String>,\n pub node_modules: Option<No...
2025-11-03T10:41:27
vuejs/vue
037449f453d14d0133c5485cffd9403c909ce5de
9566b3358f03e563d4b397470c25553b61110b9e
ensure prop default value when instantiating without propsData (fix #3693)
[ { "path": "src/core/instance/state.js", "patch": "@@ -32,8 +32,8 @@ export function initState (vm: Component) {\n \n function initProps (vm: Component) {\n const props = vm.$options.props\n- const propsData = vm.$options.propsData\n if (props) {\n+ const propsData = vm.$options.propsData || {}\n ...
2016-09-23T20:41:54
huggingface/transformers
ebbcf00ad1b06fa87effe179d128e73390255844
67097bf34055c55b886dc92014fd628c9a70e168
Adding support for Qwen3Omni (#41025) * Add Qwen3Omni * make fix-copies, import properly * nit * fix wrong setup. Why was audio_token_id renamed ? * upds * more processing fixes * yup * fix more generation tests * down to 1? * fix import issue * style, update check repo * up * fix quality at my best * fin...
[ { "path": "docs/source/en/_toctree.yml", "patch": "@@ -1143,6 +1143,8 @@\n title: Qwen2Audio\n - local: model_doc/qwen2_vl\n title: Qwen2VL\n+ - local: model_doc/qwen3_omni_moe\n+ title: Qwen3-Omni-MoE\n - local: model_doc/qwen3_vl\n title: Qwen3VL\n - l...
2025-09-21T21:46:27
ggml-org/llama.cpp
9ef536907de1b50c30e0369284898d30472a755a
21dc4ddaf21b8ed551d717e7606abd2cffbacdbf
scripts: fix compare-llama-bench.py (#15521)
[ { "path": "scripts/compare-llama-bench.py", "patch": "@@ -37,7 +37,6 @@\n \"TEXT\", \"INTEGER\", \"INTEGER\", \"INTEGER\", \"INTEGER\", \"INTEGER\",\n \"TEXT\", \"INTEGER\", \"INTEGER\", \"TEXT\", \"TEXT\", \"INTEGER\",\n \"TEXT\", \"INTEGER\", \"INTEGER\", \"INTEGER\", \"TEXT\", ...
2025-08-23T10:58:58
denoland/deno
be1ede505bf138b65d45ecbaa1b46bbce1812af1
c31e3071b88bf2bf7c172f8f936c594239b37b72
fix(ext/node): implement util.getSystemErrorMessage() (#31147) Solution for https://github.com/denoland/deno/issues/31132
[ { "path": "ext/node/polyfills/_utils.ts", "patch": "@@ -17,6 +17,7 @@ import { TextDecoder, TextEncoder } from \"ext:deno_web/08_text_encoding.js\";\n import { errorMap } from \"ext:deno_node/internal_binding/uv.ts\";\n import { codes } from \"ext:deno_node/internal/error_codes.ts\";\n import { ERR_NOT_IMPL...
2025-11-03T10:24:06
huggingface/transformers
67097bf34055c55b886dc92014fd628c9a70e168
8076e755e532dcf4083fc7a869be8d3418b9078c
Fix benchmark runner argument name (#41012)
[ { "path": ".github/workflows/benchmark_v2.yml", "patch": "@@ -12,11 +12,6 @@ on:\n required: false\n type: string\n default: ''\n- upload_to_hub:\n- description: 'Uploading results to a HuggingFace Dataset'\n- required: false\n- type: string\n- defaul...
2025-09-20T08:53:56
vuejs/vue
9566b3358f03e563d4b397470c25553b61110b9e
9fb105767200f57c9bc371b900c54c87945c2cd0
no need to return text in getValue for v-model select (fix #3729)
[ { "path": "src/platforms/web/runtime/directives/model.js", "patch": "@@ -109,7 +109,7 @@ function hasNoMatchingOption (value, options) {\n function getValue (option) {\n return '_value' in option\n ? option._value\n- : option.value || option.text\n+ : option.value\n }\n \n function onComposition...
2016-09-23T18:57:43
ggml-org/llama.cpp
21dc4ddaf21b8ed551d717e7606abd2cffbacdbf
289bf4113ef5c02d8f5eb0cf2d86683d8b8bc4d9
chat : fix debug build assertion in trim function (#15520)
[ { "path": "src/llama-chat.cpp", "patch": "@@ -16,10 +16,10 @@\n static std::string trim(const std::string & str) {\n size_t start = 0;\n size_t end = str.size();\n- while (start < end && isspace(str[start])) {\n+ while (start < end && isspace(static_cast<unsigned char>(str[start]))) {\n ...
2025-08-23T08:38:30
denoland/deno
c31e3071b88bf2bf7c172f8f936c594239b37b72
552cb3df0562fe724da8a7b61d6b5d0ac1230796
fix(ext/node): export ppid (#31137) Fix #31135
[ { "path": "ext/node/polyfills/process.ts", "patch": "@@ -75,6 +75,7 @@ export let arch = \"\";\n export let platform = isWindows ? \"win32\" : \"\"; // initialized during bootstrap\n \n export let pid = 0;\n+export let ppid = 0;\n \n let stdin, stdout, stderr;\n \n@@ -1027,7 +1028,7 @@ internals.__bootstrap...
2025-10-31T08:58:53
vuejs/vue
9fb105767200f57c9bc371b900c54c87945c2cd0
7eb6c8cfefc5c800ed773dcb94bdbac52dfc1180
Adjust nextTick implementation MutationObserver is unreliable in UIWebView on iOS >= 9.3.3, and this hasn't been fixed in iOS10. Moreover it is tedious to identify UIWebView vs. WKWebView and native Safari now that iOS10 UIWebView supports IndexedDB as well. We are switching to a setImmediate shim using window.postMe...
[ { "path": "src/core/util/env.js", "patch": "@@ -1,6 +1,5 @@\n /* @flow */\n \n-/* global MutationObserver */\n // can we use __proto__?\n export const hasProto = '__proto__' in {}\n \n@@ -9,40 +8,24 @@ export const inBrowser =\n typeof window !== 'undefined' &&\n Object.prototype.toString.call(window) !...
2016-09-23T18:46:53
huggingface/transformers
8076e755e532dcf4083fc7a869be8d3418b9078c
022c882e1432af66ef55337b5c91ad2d838365ca
Update after #41007 (#41014) * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/phimoe/test_modeling_phimoe.py", "patch": "@@ -14,7 +14,6 @@\n \n \"\"\"Testing suite for the PyTorch PhiMoE model.\"\"\"\n \n-import copy\n import unittest\n \n from parameterized import parameterized\n@@ -59,6 +58,7 @@ def forward(\n past_key_values=self.cache,\n ...
2025-09-19T19:55:46
ggml-org/llama.cpp
0a9b43e507a359ca392c037cf341f55137ad0b69
330c3d2d21b55bca5517db7d2eea2ea8f131df4a
vulkan : support ggml_mean (#15393) * vulkan : support ggml_mean * vulkan : support sum, sum_rows and mean with non-contiguous tensors * vulkan : fix subbuffer size not accounting for misalign offset * tests : add backend-op tests for non-contiguous sum_rows * cuda : require contiguous src for SUM_ROWS, MEAN suppo...
[ { "path": "ggml/src/ggml-cuda/ggml-cuda.cu", "patch": "@@ -3485,11 +3485,11 @@ static bool ggml_backend_cuda_device_supports_op(ggml_backend_dev_t dev, const g\n case GGML_OP_CONV_TRANSPOSE_2D:\n case GGML_OP_POOL_2D:\n case GGML_OP_SUM:\n- case GGML_OP_SUM_ROWS:\n- cas...
2025-08-23T06:35:21
denoland/deno
552cb3df0562fe724da8a7b61d6b5d0ac1230796
e83574015bbf09b4f6a3877ddb892637b3c09653
fix(ext/node): respects `flag` option on `fs.readfile` and `fs.readfilesync` (#31129) Closes #31099
[ { "path": "cli/rt/file_system.rs", "patch": "@@ -546,6 +546,7 @@ impl sys_traits::BaseFsRead for DenoRtSys {\n // we should flip this so that the `deno_fs::FileSystem` implementation uses `sys_traits`\n // rather than this calling into `deno_fs::FileSystem`\n &CheckedPath::unsafe_new...
2025-10-31T08:32:36
huggingface/transformers
022c882e1432af66ef55337b5c91ad2d838365ca
966b3dbcbefaa358ce1fe51b687b756fd5b877ed
Fix Glm4v test (#41011) fix
[ { "path": "tests/models/glm4v_moe/test_modeling_glm4v_moe.py", "patch": "@@ -297,6 +297,7 @@ def test_inputs_embeds_matches_input_ids(self):\n \n \n @require_torch\n+@slow\n class Glm4vMoeIntegrationTest(unittest.TestCase):\n model = None\n \n@@ -310,7 +311,8 @@ def get_model(cls):\n \n @classmethod...
2025-09-19T16:54:26
vuejs/vue
4785afd15475d548ec529249b5c50770e74bf33c
089c1458cc8d29131b034bb97b866d73448cddd0
improve MutationObserver bug detection for iOS 10
[ { "path": "src/core/util/env.js", "patch": "@@ -16,16 +16,19 @@ export const devtools = inBrowser && window.__VUE_DEVTOOLS_GLOBAL_HOOK__\n export const UA = inBrowser && window.navigator.userAgent.toLowerCase()\n const isIos = UA && /(iphone|ipad|ipod|ios)/i.test(UA)\n const iosVersionMatch = UA && isIos &&...
2016-09-21T04:29:53
ggml-org/llama.cpp
45363632cbd593537d541e81b600242e0b3d47fc
32732f2459a598606055f0403f0e4ec148d06d68
ggml WebGPU: add support for quantization types (#15440) * Begin work on set_rows * Work on set rows * Add error buffers for reporting unsupported SET_ROWS indices * Remove extra comments * Work on templating for different types in shaders * Work on shader type generation * Working q4_0 mul_mat and some templati...
[ { "path": "ggml/src/ggml-webgpu/CMakeLists.txt", "patch": "@@ -20,8 +20,8 @@ add_custom_command(\n COMMAND ${CMAKE_COMMAND} -E make_directory ${SHADER_OUTPUT_DIR}\n COMMAND ${CMAKE_COMMAND} -E env PYTHONIOENCODING=utf-8\n ${Python3_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/wgsl-shaders/embed_w...
2025-08-22T18:28:03
denoland/deno
40de911154f38417a74eff7eb94c408b2a3f914d
1b5f3112af364a3327b26f720746819c4f20f20d
fix(ext/net): support IPv6 zone indices in Deno.connect() (#31123) Fixes https://github.com/denoland/deno/issues/30956
[ { "path": "runtime/permissions/lib.rs", "patch": "@@ -9,6 +9,7 @@ use std::hash::Hash;\n use std::io::Write;\n use std::net::IpAddr;\n use std::net::Ipv6Addr;\n+use std::net::SocketAddr;\n use std::ops::Deref;\n use std::path::Path;\n use std::path::PathBuf;\n@@ -1443,6 +1444,16 @@ pub enum HostParseError {...
2025-10-30T14:55:52
huggingface/transformers
966b3dbcbefaa358ce1fe51b687b756fd5b877ed
04bf4112f2e4b27d39d74529f6f4fb46080f19cc
Fix `PhimoeIntegrationTest` (#41007) * fix * fix * fix * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "tests/models/phimoe/test_modeling_phimoe.py", "patch": "@@ -14,12 +14,14 @@\n \n \"\"\"Testing suite for the PyTorch PhiMoE model.\"\"\"\n \n+import copy\n import unittest\n \n from parameterized import parameterized\n \n from transformers import PhimoeConfig, StaticCache, is_torch_available\n fr...
2025-09-19T16:43:46
vuejs/vue
1fe9ba61d7f0688398f445484446f48fd13c7a84
ccd8d587d67228cf9f202b231419e91a8ab106a3
fix select2 e2e test
[ { "path": "examples/select2/index.html", "patch": "@@ -55,7 +55,7 @@\n watch: {\n value: function (value) {\n // update value\n- $(this.$el).select2('val', value)\n+ $(this.$el).val(value).trigger('change')\n },\n options: function (options) {\n ...
2016-09-19T16:35:07
ggml-org/llama.cpp
ad5c975c2d0297124fad210776ef8eed6b90d578
4afb0a746f22abaa545b3ebdb76a400d7da3a713
ggml-cpu: Support Q5_0 and Q5_1 on s390x (#15486) * ggml-cpu: initial q5_0 impl for s390x Signed-off-by: Aaron Teo <aaron.teo1@ibm.com> * ggml-cpu: updated q5_0 code for better performance Signed-off-by: Aaron Teo <aaron.teo1@ibm.com> * ggml-cpu: use optimised hsum for better performance Signed-off-by: Aaron Teo ...
[ { "path": "docs/build-s390x.md", "patch": "@@ -265,8 +265,9 @@ IBM VXE/VXE2 SIMD acceleration depends on the BLAS implementation. It is strongl\n | BF16 | 🚫 | 🚫 | ❓ | ❓ |\n | Q4_0 | ✅ | ✅ | ❓ | ❓ |\n | Q4_1 | ✅ | ✅ | ❓ | ❓ |\n-| Q5_0 ...
2025-08-22T08:11:04
denoland/deno
12a6585c663d91c68d5215abf1607dd30c12c320
e770db547a0f08f297f7d1622e1c71d8cbcdb6b3
fix(windows): strip periods and trailing slashes when normalizing paths (#31131) This is specifically for the application code. Not for any JS APIs.
[ { "path": "Cargo.lock", "patch": "@@ -2720,9 +2720,9 @@ dependencies = [\n \n [[package]]\n name = \"deno_path_util\"\n-version = \"0.6.3\"\n+version = \"0.6.4\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"a4f70f7cbc884556f08781aaa75aef177d15bfee99e4fc40c25fa74514c678...
2025-10-29T19:29:44
huggingface/transformers
04bf4112f2e4b27d39d74529f6f4fb46080f19cc
dfc230389c2cfcbd23718594363d097b89233e25
🚨 [lightglue] fix: matches order changed because of early stopped indices (#40859) * fix: bug that made early stop change order of matches * fix: applied code suggestion Co-authored-by: Pavel Iakubovskii <qubvel@gmail.com> * fix: applied code suggestion to modular * fix: integration tests --------- Co-authored-...
[ { "path": "src/transformers/models/lightglue/modeling_lightglue.py", "patch": "@@ -628,6 +628,10 @@ def _concat_early_stopped_outputs(\n matching_scores,\n ):\n early_stops_indices = torch.stack(early_stops_indices)\n+ # Rearrange tensors to have the same order as the input batch\...
2025-09-19T15:41:22
vuejs/vue
56960b5fbcf82d2160a7c9645ebddecc258bc0ec
d6a7568891d0c3368471322de5d730172d92b9e4
support object looseEqual in v-model (fix #3673)
[ { "path": "flow/component.js", "patch": "@@ -89,6 +89,10 @@ declare interface Component {\n _n: (value: string) => number | string;\n // empty vnode\n _e: () => VNode;\n+ // loose equal\n+ _q: (a: mixed, b: mixed) => boolean;\n+ // loose indexOf\n+ _i: (arr: Array<mixed>, val: mixed) => number;\n ...
2016-09-14T15:35:30
ggml-org/llama.cpp
a0f98dd604d34826eb5ea2560d1e23fe726921df
54a241f505d515d625767b993bfd573ecee306b9
CANN: Optimize RMS_NORM using cache (#15419) * [CANN] Optimize RMS_NORM using cache Signed-off-by: noemotiovon <757486878@qq.com> * fix typo Signed-off-by: noemotiovon <757486878@qq.com> * fix review comment Signed-off-by: noemotiovon <757486878@qq.com> * codestyle adjustment Signed-off-by: noemotiovon <7574868...
[ { "path": "ggml/src/ggml-cann/aclnn_ops.cpp", "patch": "@@ -867,6 +867,86 @@ static aclTensor* aclnn_values(ggml_backend_cann_context& ctx, void* buffer,\n return acl_tensor;\n }\n \n+/**\n+ * @brief Fills a tensor with a scalar value.\n+ *\n+ * This function fills the destination tensor `acl_dst` with ...
2025-08-22T06:12:07
denoland/deno
e770db547a0f08f297f7d1622e1c71d8cbcdb6b3
e39df87fabecc745bc12102c949f5f7dc95a3808
fix(ext/node): implement StatementSync#columns() method (#31119) Fixes https://github.com/denoland/deno/issues/31110
[ { "path": "ext/node/ops/sqlite/statement.rs", "patch": "@@ -804,4 +804,130 @@ impl StatementSync {\n Ok(sql)\n }\n }\n+\n+ fn columns<'a>(\n+ &self,\n+ scope: &mut v8::PinScope<'a, '_>,\n+ ) -> Result<v8::Local<'a, v8::Array>, SqliteError> {\n+ v8_static_strings! {\n+ NAME = \"na...
2025-10-29T10:22:29
huggingface/transformers
8010f5d1d9e16949d3dff49873811636070dcdcb
5bf633b32a1bc5cc5c56445247ecebd349b5d063
Patch more `unittest.case.TestCase.assertXXX` methods (#41008) fix Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "src/transformers/testing_utils.py", "patch": "@@ -3732,6 +3732,18 @@ def patch_testing_methods_to_collect_info():\n _patch_with_call_info(torch.testing, \"assert_close\", _parse_call_info, target_args=(\"actual\", \"expected\"))\n \n _patch_with_call_info(unittest.case.TestCase, \"ass...
2025-09-19T14:38:12
vuejs/vue
d6a7568891d0c3368471322de5d730172d92b9e4
2b588b754e5d9c2eea31c56eb735afd6ce37ec5c
improve v-bind implementation and make it work on components (fix #3670)
[ { "path": "flow/compiler.js", "patch": "@@ -50,8 +50,6 @@ declare type ASTElementHandlers = {\n [key: string]: ASTElementHandler | Array<ASTElementHandler>;\n }\n \n-declare type ASTElementHooks = { [key: string]: Array<string> }\n-\n declare type ASTDirective = {\n name: string;\n value: string;\n@@ ...
2016-09-14T14:14:14
ggml-org/llama.cpp
54a241f505d515d625767b993bfd573ecee306b9
cd36b5e5c7fed2a3ac671dd542d579ca40b48b54
sched : fix possible use of wrong ids tensor when offloading moe prompt processing (#15488)
[ { "path": "common/arg.cpp", "patch": "@@ -1755,7 +1755,7 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n [](common_params & params) {\n params.warmup = false;\n }\n- ).set_examples({LLAMA_EXAMPLE_MAIN, LLAMA_EXAMPLE_SERVER, LLAMA_EXAMPLE_E...
2025-08-21T21:09:32
denoland/deno
1b07f0295dd91f393966f953099ee90505a97e50
e90b29375a7aff541892c22214eebb6e95d2c6be
fix(windows): re-allow spawning bat and cmd files (#31118)
[ { "path": "ext/process/lib.rs", "patch": "@@ -752,26 +752,6 @@ fn compute_run_cmd_and_check_permissions(\n command: arg_cmd.to_string(),\n error: Box::new(e),\n })?;\n- // Undocumented feature of CreateProcess API allows spawning batch files directly\n- // without proper argument escaping....
2025-10-28T20:39:35
huggingface/transformers
2a538b2ed4a849b99cd790731f51f1d221a318f4
96a3e898cd1a0e1864e79b48c3f6c804c7a56780
fix dict like init for ModelOutput (#41002) * fix dict like init * style
[ { "path": "src/transformers/utils/generic.py", "patch": "@@ -318,6 +318,8 @@ def __post_init__(self):\n # if we provided an iterator as first field and the iterator is a (key, value) iterator\n # set the associated fields\n if first_field_iterator:\n+ # res...
2025-09-19T14:14:44
ggml-org/llama.cpp
9ad5e60dba38a6718366b7ac43e7d8e8abdc36c9
715a6db02ccb16284837885f2c6fab05d8f7a6ee
examples : fix some typos in examples/model-conversion/README.md (#15477) Signed-off-by: Jie Fu <jiefu@tencent.com>
[ { "path": "examples/model-conversion/README.md", "patch": "@@ -6,7 +6,7 @@ The motivation for having this is that the conversion process can often be an\n iterative process, where the original model is inspected, converted, updates\n made to llama.cpp, converted again, etc. Once the model has been converted...
2025-08-21T14:53:13
denoland/deno
58f21ae59765c40e99dcb6d94d0b449cc6601abd
ee6c66b9e9b8277327811564a34124b109927bd3
fix(ext/node): inconsistent error message thrown by AssertionError (#31089) Closes #31082
[ { "path": "ext/node/lib.rs", "patch": "@@ -551,8 +551,6 @@ deno_core::extension!(deno_node,\n \"_util/async.ts\",\n \"_util/os.ts\",\n \"_util/std_asserts.ts\",\n- \"_util/std_fmt_colors.ts\",\n- \"_util/std_testing_diff.ts\",\n \"_utils.ts\",\n \"_zlib_binding.mjs\",\n \"asser...
2025-10-28T08:51:09
huggingface/transformers
96a3e898cd1a0e1864e79b48c3f6c804c7a56780
98c8523434672da086982420faba9350431c270c
RUFF fix on CI scripts (#40805) Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
[ { "path": ".circleci/create_circleci_config.py", "patch": "@@ -16,10 +16,9 @@\n import argparse\n import copy\n import os\n-import random\n from dataclasses import dataclass\n-from typing import Any, Dict, List, Optional\n-import glob\n+from typing import Any, Optional\n+\n import yaml\n \n \n@@ -82,15 +81,...
2025-09-19T13:50:26
ggml-org/llama.cpp
715a6db02ccb16284837885f2c6fab05d8f7a6ee
ad294df03ff2dccd227c3fee653166f3d78b23a4
kv-cache : drop the "unified" prefix (#15467) * kv-cache : drop the "unified" prefix ggml-ci * cont : fix comment [no ci]
[ { "path": "include/llama.h", "patch": "@@ -64,8 +64,6 @@ extern \"C\" {\n \n typedef struct llama_memory_i * llama_memory_t;\n \n- struct llama_kv_cache; // DEPRECATED (use llama_memory instead)\n-\n typedef int32_t llama_pos;\n typedef int32_t llama_token;\n typedef int32_t llama_seq_id;...
2025-08-21T14:00:33